# data
This directory contains static external resources used by the codebase.

## Orders Spec

### Files

* `orders_product_bundle_2024-08-12.json`

### Description

This file was downloaded from the Planet
[Product Bundles Reference](https://developers.planet.com/docs/orders/product-bundles-reference/)
page and is stored without any adjustments.

## GeoJSON Schemas

### Files

* `Feature.json`

### Description

These files were generated by cloning and building
[geojson/schema](https://github.com/geojson/schema)
([commit](https://github.com/geojson/schema/commit/ed4bc7b05e6d6751be12b867ca89a30d6aba7650)). These can also be accessed from [geojson.org](https://geojson.org/).
